@@ -5,7 +5,6 @@ from qtpy import QtWidgets
 from qtpy.QtCore import Qt
 from qtpy.QtCore import Signal
 
-from ..compat import uchr
 from ..git import STDOUT
 from ..i18n import N_
 from ..interaction import Interaction
@@ -143,7 +142,9 @@ class BranchesTreeWidget(standard.TreeWidget):
 
         self._visible = False
         self._needs_refresh = False
+        self._branch_details_in_progress = False
         self._tree_states = None
+        self._name_filter = ''
 
         self.updated.connect(self.refresh, type=Qt.QueuedConnection)
         context.model.updated.connect(self.updated)
@@ -154,6 +155,11 @@ class BranchesTreeWidget(standard.TreeWidget):
         # Checkout branch when double clicked
         self.doubleClicked.connect(self.checkout_action)
 
+    def set_name_filter(self, value):
+        """Update the name filter and rebuild the tree to include only matching refs"""
+        self._name_filter = value
+        self.refresh()
+
     def refresh(self):
         """Refresh the UI widgets to match the current state"""
         self._needs_refresh = True
@@ -170,17 +176,17 @@ class BranchesTreeWidget(standard.TreeWidget):
         self._tree_states = self._save_tree_state()
         ellipsis = icons.ellipsis()
 
-        local_tree = create_tree_entries(model.local_branches)
+        local_tree = create_tree_entries(model.local_branches, self._name_filter)
         local_tree.basename = N_('Local')
         local = create_toplevel_item(local_tree, icon=icons.branch(), ellipsis=ellipsis)
 
-        remote_tree = create_tree_entries(model.remote_branches)
+        remote_tree = create_tree_entries(model.remote_branches, self._name_filter)
         remote_tree.basename = N_('Remote')
         remote = create_toplevel_item(
             remote_tree, icon=icons.branch(), ellipsis=ellipsis
         )
 
-        tags_tree = create_tree_entries(model.tags)
+        tags_tree = create_tree_entries(model.tags, self._name_filter)
         tags_tree.basename = N_('Tags')
         tags = create_toplevel_item(tags_tree, icon=icons.tag(), ellipsis=ellipsis)
 
@@ -338,7 +344,9 @@ class BranchesTreeWidget(standard.TreeWidget):
         if item is not None:
             expand_item_parents(item)
             item.setIcon(0, icons.star())
-
+            if self._branch_details_in_progress:
+                return
+            self._branch_details_in_progress = True
             branch_details_task = BranchDetailsTask(
                 context, current_branch, self.git_helper
             )
@@ -354,13 +362,14 @@ class BranchesTreeWidget(standard.TreeWidget):
         if current_branch and tracked_branch and item is not None:
             status_str = ''
             if ahead > 0:
-                status_str += f'{uchr(0x2191)}{ahead}'
+                status_str += f'{chr(0x2191)}{ahead}'
 
             if behind > 0:
-                status_str += f'  {uchr(0x2193)}{behind}'
+                status_str += f'  {chr(0x2193)}{behind}'
 
             if status_str:
                 item.setText(0, f'{item.text(0)}\t{status_str}')
+        self._branch_details_in_progress = False
 
     def git_action_async(
         self,
@@ -568,7 +577,7 @@ class TreeEntry:
         self.children = children
 
 
-def create_tree_entries(names):
+def create_tree_entries(names, name_filter):
     """Create a nested tree structure with a single root TreeEntry.
 
     When names == ['xxx/abc', 'xxx/def'] the result will be::
@@ -599,12 +608,13 @@ def create_tree_entries(names):
     """
     # Phase 1: build a nested dictionary representing the intermediate
     # names in the branches, e.g. {'xxx': {'abc': {}, 'def': {}}}
-    tree_names = create_name_dict(names)
+    filtered_names = [name for name in names if name_filter in name]
+    tree_names = create_name_dict(filtered_names)
 
     # Loop over the names again, this time we'll create tree entries
     entries = {}
     root = TreeEntry(None, None, [])
-    for item in names:
+    for item in filtered_names:
         cur_names = tree_names
         cur_entries = entries
         tree = root
@@ -796,7 +806,7 @@ class BranchesFilterWidget(QtWidgets.QWidget):
         self.text = text.LineEdit(parent=self, clear_button=True)
         self.text.setToolTip(hint)
         self.setFocusProxy(self.text)
-        self._filter = None
+        self._filter = ''
 
         self.main_layout = qtutils.hbox(defs.no_margin, defs.spacing, self.text)
         self.setLayout(self.main_layout)
@@ -808,20 +818,8 @@ class BranchesFilterWidget(QtWidgets.QWidget):
         value = get(self.text)
         if value == self._filter:
             return
-        self._apply_bold(self._filter, False)
         self._filter = value
-        if value:
-            self._apply_bold(value, True)
-
-    def _apply_bold(self, value, is_bold):
-        match = Qt.MatchContains | Qt.MatchRecursive
-        children = self.tree.findItems(value, match)
-
-        for child in children:
-            if child.childCount() == 0:
-                font = child.font(0)
-                font.setBold(is_bold)
-                child.setFont(0, font)
+        self.tree.set_name_filter(value)
 
 
 def _set_upstream_branch(context, branch, upstream_branch, parent):
