@@ -162,6 +162,7 @@ scissors
         self.autotemplate = qtutils.checkbox(checked=False)
         self.merge_diffstat = qtutils.checkbox(checked=True)
         self.display_untracked = qtutils.checkbox(checked=True)
+        self.rebase_update_refs = qtutils.checkbox(checked=False)
         self.show_path = qtutils.checkbox(checked=True)
         self.update_index = qtutils.checkbox(checked=True)
         self.http_proxy = QtWidgets.QLineEdit()
@@ -199,6 +200,10 @@ scissors
         self.add_row(N_('Number of Diff Context Lines'), self.diff_context)
         self.add_row(N_('Summarize Merge Commits'), self.merge_summary)
         self.add_row(N_('Enable Filesystem Monitoring'), self.inotify)
+        self.add_row(
+            N_('Update stacked branches/refs when rebasing'),
+            self.rebase_update_refs,
+        )
         self.add_row(
             N_('Automatically Load Commit Message Template'), self.autotemplate
         )
@@ -243,6 +248,10 @@ scissors
                 self.patches_directory,
                 Defaults.patches_directory,
             ),
+            prefs.REBASE_UPDATE_REFS: (
+                self.rebase_update_refs,
+                Defaults.rebase_update_refs,
+            ),
             prefs.SHOW_PATH: (self.show_path, Defaults.show_path),
             prefs.USER_NAME: (self.name, ''),
             prefs.USER_EMAIL: (self.email, ''),
@@ -472,8 +481,8 @@ class PreferencesView(standard.Dialog):
 
         self.tab_bar = QtWidgets.QTabBar()
         self.tab_bar.setDrawBase(False)
-        self.tab_bar.addTab(N_('All Repositories'))
         self.tab_bar.addTab(N_('Current Repository'))
+        self.tab_bar.addTab(N_('All Repositories'))
         self.tab_bar.addTab(N_('Settings'))
         self.tab_bar.addTab(N_('Appearance'))
 
@@ -484,8 +493,8 @@ class PreferencesView(standard.Dialog):
         self.appearance = AppearanceWidget(self.appearance_form, self)
 
         self.stack_widget = QtWidgets.QStackedWidget()
-        self.stack_widget.addWidget(self.user_form)
         self.stack_widget.addWidget(self.repo_form)
+        self.stack_widget.addWidget(self.user_form)
         self.stack_widget.addWidget(self.options_form)
         self.stack_widget.addWidget(self.appearance)
 
@@ -494,6 +503,14 @@ class PreferencesView(standard.Dialog):
         self.button_layout = qtutils.hbox(
             defs.no_margin, defs.spacing, qtutils.STRETCH, self.close_button
         )
+        # If the user already has the user.email and user.name configured then default
+        # to editing the current repo's config instead of the user-wide settings.
+        if self.context.cfg.get('user.name') and self.context.cfg.get('user.email'):
+            index = 0
+        else:
+            index = 1
+        self.stack_widget.setCurrentIndex(index)
+        self.tab_bar.setCurrentIndex(index)
 
         self.main_layout = qtutils.vbox(
             defs.margin,
@@ -510,7 +527,7 @@ class PreferencesView(standard.Dialog):
         qtutils.connect_button(self.close_button, self.accept)
         qtutils.add_close_action(self)
 
-        self.update_widget(0)
+        self.update_widget(index)
 
     def update_widget(self, idx):
         widget = self.stack_widget.widget(idx)
